summaryrefslogtreecommitdiff
path: root/Master/tlpkg/tlperl/lib/Pod/Text/Overstrike.pm
diff options
context:
space:
mode:
Diffstat (limited to 'Master/tlpkg/tlperl/lib/Pod/Text/Overstrike.pm')
-rw-r--r--Master/tlpkg/tlperl/lib/Pod/Text/Overstrike.pm19
1 files changed, 10 insertions, 9 deletions
diff --git a/Master/tlpkg/tlperl/lib/Pod/Text/Overstrike.pm b/Master/tlpkg/tlperl/lib/Pod/Text/Overstrike.pm
index f5dce0230f8..1592026e9f7 100644
--- a/Master/tlpkg/tlperl/lib/Pod/Text/Overstrike.pm
+++ b/Master/tlpkg/tlperl/lib/Pod/Text/Overstrike.pm
@@ -12,9 +12,9 @@
# independent.
#
# Created by Joe Smith <Joe.Smith@inwap.com> 30-Nov-2000
# (based on Pod::Text::Color by Russ Allbery <rra@stanford.edu>)
# Copyright 2000 Joe Smith <Joe.Smith@inwap.com>.
-# Copyright 2001, 2004, 2008 Russ Allbery <rra@stanford.edu>.
+# Copyright 2001, 2004, 2008, 2014 Russ Allbery <rra@cpan.org>.
#
# This program is free software; you may redistribute it and/or modify it
# under the same terms as Perl itself.
@@ -25,16 +25,17 @@
package Pod::Text::Overstrike;
-require 5.004;
-
-use Pod::Text ();
-
+use 5.006;
use strict;
+use warnings;
+
use vars qw(@ISA $VERSION);
+use Pod::Text ();
+
@ISA = qw(Pod::Text);
-$VERSION = '2.05';
+$VERSION = '4.07';
##############################################################################
# Overrides
@@ -195,12 +196,12 @@ Perl core distribution as of 5.6.0.
=head1 AUTHOR
Joe Smith <Joe.Smith@inwap.com>, using the framework created by Russ Allbery
-<rra@stanford.edu>.
+<rra@cpan.org>.
=head1 COPYRIGHT AND LICENSE
Copyright 2000 by Joe Smith <Joe.Smith@inwap.com>.
-Copyright 2001, 2004, 2008 by Russ Allbery <rra@stanford.edu>.
+Copyright 2001, 2004, 2008 by Russ Allbery <rra@cpan.org>.
This program is free software; you may redistribute it and/or modify it
under the same terms as Perl itself.
@@ -12,9 +12,9 @@
#
# Created by Joe Smith <Joe.Smith@inwap.com> 30-Nov-2000
-# (based on Pod::Text::Color by Russ Allbery <rra@stanford.edu>)
+# (based on Pod::Text::Color by Russ Allbery <rra@cpan.org>)
# Copyright 2000 Joe Smith <Joe.Smith@inwap.com>.